"""TikTok-Uploader entry point script"""

from tiktok_uploader import cli

def main():
	"""
	Entry point for TikTok-Uploader, makes a call to CLI
	"""
	cli.cli()

if __name__ == '__main__':
	main()
